<?php

namespace StructType;

use \WsdlToPhp\PackageBase\AbstractStructBase;

/**
 * This class stands for ToomRewe StructType
 * Meta information extracted from the WSDL
 * - documentation: TOOM/REWE internal | TOOM/REWE intern
 * @subpackage Structs
 */
class ToomRewe extends AbstractStructBase
{
    /**
     * The DeliveryTerms
     * Meta information extracted from the WSDL
     * - documentation: Terms of delivery | Frankatur
     * - fixed: 022
     * - maxOccurs: 1
     * - minOccurs: 1
     * @var string
     */
    public $DeliveryTerms;
    /**
     * The FreightCostsPaidBy
     * Meta information extracted from the WSDL
     * - documentation: Freight costs paid by | Frachtkosten trägt
     * - maxOccurs: 1
     * - minOccurs: 1
     * @var string
     */
    public $FreightCostsPaidBy;
    /**
     * The Reference
     * Meta information extracted from the WSDL
     * - documentation: Shipment reference | Sendungsreferenz
     * - base: xsd:string
     * - maxLength: 15
     * - maxOccurs: 1
     * - minLength: 1
     * - minOccurs: 1
     * @var string
     */
    public $Reference;
    /**
     * The Address
     * Meta information extracted from the WSDL
     * - maxOccurs: 1
     * - minOccurs: 1
     * @var \StructType\Address
     */
    public $Address;
    /**
     * The Position
     * Meta information extracted from the WSDL
     * - maxOccurs: 4
     * - minOccurs: 1
     * @var \StructType\Position[]
     */
    public $Position;
    /**
     * The GoodsValue
     * Meta information extracted from the WSDL
     * - documentation: Goods value (in euro) | Warenwert (in Euro)
     * - base: xsd:decimal
     * - fractionDigits: 2
     * - maxInclusive: 9999999999.99
     * - maxOccurs: 1
     * - minInclusive: 0.00
     * - minOccurs: 0
     * - pattern: [1-9]{1}[0-9]{0,9}.[0-9]{2}
     * - totalDigits: 12
     * @var float
     */
    public $GoodsValue;
    /**
     * The Ordertext1
     * Meta information extracted from the WSDL
     * - documentation: Ordertext 1 | Auftragstext 1
     * - base: xsd:string
     * - maxLength: 33
     * - maxOccurs: 1
     * - minLength: 1
     * - minOccurs: 0
     * @var string
     */
    public $Ordertext1;
    /**
     * The Ordertext2
     * Meta information extracted from the WSDL
     * - documentation: Ordertext 2 | Auftragstext 2
     * - base: xsd:string
     * - maxLength: 33
     * - maxOccurs: 1
     * - minLength: 1
     * - minOccurs: 0
     * @var string
     */
    public $Ordertext2;
    /**
     * The Pitches
     * Meta information extracted from the WSDL
     * - documentation: Pitches | Stellplätze
     * - base: xsd:string
     * - maxLength: 3
     * - maxOccurs: 1
     * - minLength: 1
     * - minOccurs: 0
     * @var string
     */
    public $Pitches;
    /**
     * The Volume
     * Meta information extracted from the WSDL
     * - documentation: Volume (in m3) | Volumen (in m3)
     * - base: xsd:decimal
     * - maxInclusive: 99.999
     * - maxOccurs: 1
     * - minInclusive: 0.000
     * - minOccurs: 0
     * - pattern: [0-9]{1,2}.[0-9]{3}
     * @var float
     */
    public $Volume;
    /**
     * The LoadingunitsFP
     * Meta information extracted from the WSDL
     * - documentation: Amount of loadingunits FP | Anzahl Ladehilfsmittel FP
     * - base: xsd:string
     * - maxLength: 3
     * - maxOccurs: 1
     * - minLength: 1
     * - minOccurs: 0
     * @var string
     */
    public $LoadingunitsFP;
    /**
     * The LoadingunitsGP
     * Meta information extracted from the WSDL
     * - documentation: Amount of loadingunits GP | Anzahl Ladehilfsmittel GP
     * - base: xsd:string
     * - maxLength: 3
     * - maxOccurs: 1
     * - minLength: 1
     * - minOccurs: 0
     * @var string
     */
    public $LoadingunitsGP;
    /**
     * Constructor method for ToomRewe
     * @uses ToomRewe::setDeliveryTerms()
     * @uses ToomRewe::setFreightCostsPaidBy()
     * @uses ToomRewe::setReference()
     * @uses ToomRewe::setAddress()
     * @uses ToomRewe::setPosition()
     * @uses ToomRewe::setGoodsValue()
     * @uses ToomRewe::setOrdertext1()
     * @uses ToomRewe::setOrdertext2()
     * @uses ToomRewe::setPitches()
     * @uses ToomRewe::setVolume()
     * @uses ToomRewe::setLoadingunitsFP()
     * @uses ToomRewe::setLoadingunitsGP()
     * @param string $deliveryTerms
     * @param string $freightCostsPaidBy
     * @param string $reference
     * @param \StructType\Address $address
     * @param \StructType\Position[] $position
     * @param float $goodsValue
     * @param string $ordertext1
     * @param string $ordertext2
     * @param string $pitches
     * @param float $volume
     * @param string $loadingunitsFP
     * @param string $loadingunitsGP
     */
    public function __construct($deliveryTerms = null, $freightCostsPaidBy = null, $reference = null, \StructType\Address $address = null, array $position = array(), $goodsValue = null, $ordertext1 = null, $ordertext2 = null, $pitches = null, $volume = null, $loadingunitsFP = null, $loadingunitsGP = null)
    {
        $this
            ->setDeliveryTerms($deliveryTerms)
            ->setFreightCostsPaidBy($freightCostsPaidBy)
            ->setReference($reference)
            ->setAddress($address)
            ->setPosition($position)
            ->setGoodsValue($goodsValue)
            ->setOrdertext1($ordertext1)
            ->setOrdertext2($ordertext2)
            ->setPitches($pitches)
            ->setVolume($volume)
            ->setLoadingunitsFP($loadingunitsFP)
            ->setLoadingunitsGP($loadingunitsGP);
    }
    /**
     * Get DeliveryTerms value
     * @return string
     */
    public function getDeliveryTerms()
    {
        return $this->DeliveryTerms;
    }
    /**
     * Set DeliveryTerms value
     * @uses \EnumType\CodelistDeliveryterms::valueIsValid()
     * @uses \EnumType\CodelistDeliveryterms::getValidValues()
     * @throws \InvalidArgumentException
     * @param string $deliveryTerms
     * @return \StructType\ToomRewe
     */
    public function setDeliveryTerms($deliveryTerms = null)
    {
        // validation for constraint: enumeration
        if (!\EnumType\CodelistDeliveryterms::valueIsValid($deliveryTerms)) {
            throw new \InvalidArgumentException(sprintf('Invalid value(s) %s, please use one of: %s from enumeration class \EnumType\CodelistDeliveryterms', is_array($deliveryTerms) ? implode(', ', $deliveryTerms) : var_export($deliveryTerms, true), implode(', ', \EnumType\CodelistDeliveryterms::getValidValues())), __LINE__);
        }
        $this->DeliveryTerms = $deliveryTerms;
        return $this;
    }
    /**
     * Get FreightCostsPaidBy value
     * @return string
     */
    public function getFreightCostsPaidBy()
    {
        return $this->FreightCostsPaidBy;
    }
    /**
     * Set FreightCostsPaidBy value
     * @uses \EnumType\CodelistFreightCostsPaidBy::valueIsValid()
     * @uses \EnumType\CodelistFreightCostsPaidBy::getValidValues()
     * @throws \InvalidArgumentException
     * @param string $freightCostsPaidBy
     * @return \StructType\ToomRewe
     */
    public function setFreightCostsPaidBy($freightCostsPaidBy = null)
    {
        // validation for constraint: enumeration
        if (!\EnumType\CodelistFreightCostsPaidBy::valueIsValid($freightCostsPaidBy)) {
            throw new \InvalidArgumentException(sprintf('Invalid value(s) %s, please use one of: %s from enumeration class \EnumType\CodelistFreightCostsPaidBy', is_array($freightCostsPaidBy) ? implode(', ', $freightCostsPaidBy) : var_export($freightCostsPaidBy, true), implode(', ', \EnumType\CodelistFreightCostsPaidBy::getValidValues())), __LINE__);
        }
        $this->FreightCostsPaidBy = $freightCostsPaidBy;
        return $this;
    }
    /**
     * Get Reference value
     * @return string
     */
    public function getReference()
    {
        return $this->Reference;
    }
    /**
     * Set Reference value
     * @param string $reference
     * @return \StructType\ToomRewe
     */
    public function setReference($reference = null)
    {
        // validation for constraint: string
        if (!is_null($reference) && !is_string($reference)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($reference, true), gettype($reference)), __LINE__);
        }
        // validation for constraint: maxLength(15)
        if (!is_null($reference) && mb_strlen($reference) > 15) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 15', mb_strlen($reference)), __LINE__);
        }
        // validation for constraint: minLength(1)
        if (!is_null($reference) && mb_strlen($reference) < 1) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be greater than or equal to 1', mb_strlen($reference)), __LINE__);
        }
        $this->Reference = $reference;
        return $this;
    }
    /**
     * Get Address value
     * @return \StructType\Address
     */
    public function getAddress()
    {
        return $this->Address;
    }
    /**
     * Set Address value
     * @param \StructType\Address $address
     * @return \StructType\ToomRewe
     */
    public function setAddress(\StructType\Address $address = null)
    {
        $this->Address = $address;
        return $this;
    }
    /**
     * Get Position value
     * @return \StructType\Position[]
     */
    public function getPosition()
    {
        return $this->Position;
    }
    /**
     * This method is responsible for validating the values passed to the setPosition method
     * This method is willingly generated in order to preserve the one-line inline validation within the setPosition method
     * @param array $values
     * @return string A non-empty message if the values does not match the validation rules
     */
    public static function validatePositionForArrayConstraintsFromSetPosition(array $values = array())
    {
        $message = '';
        $invalidValues = [];
        foreach ($values as $toomRewePositionItem) {
            // validation for constraint: itemType
            if (!$toomRewePositionItem instanceof \StructType\Position) {
                $invalidValues[] = is_object($toomRewePositionItem) ? get_class($toomRewePositionItem) : sprintf('%s(%s)', gettype($toomRewePositionItem), var_export($toomRewePositionItem, true));
            }
        }
        if (!empty($invalidValues)) {
            $message = sprintf('The Position property can only contain items of type \StructType\Position, %s given', is_object($invalidValues) ? get_class($invalidValues) : (is_array($invalidValues) ? implode(', ', $invalidValues) : gettype($invalidValues)));
        }
        unset($invalidValues);
        return $message;
    }
    /**
     * Set Position value
     * @throws \InvalidArgumentException
     * @param \StructType\Position[] $position
     * @return \StructType\ToomRewe
     */
    public function setPosition(array $position = array())
    {
        // validation for constraint: array
        if ('' !== ($positionArrayErrorMessage = self::validatePositionForArrayConstraintsFromSetPosition($position))) {
            throw new \InvalidArgumentException($positionArrayErrorMessage, __LINE__);
        }
        // validation for constraint: maxOccurs(4)
        if (is_array($position) && count($position) > 4) {
            throw new \InvalidArgumentException(sprintf('Invalid count of %s, the number of elements contained by the property must be less than or equal to 4', count($position)), __LINE__);
        }
        $this->Position = $position;
        return $this;
    }
    /**
     * Add item to Position value
     * @throws \InvalidArgumentException
     * @param \StructType\Position $item
     * @return \StructType\ToomRewe
     */
    public function addToPosition(\StructType\Position $item)
    {
        // validation for constraint: itemType
        if (!$item instanceof \StructType\Position) {
            throw new \InvalidArgumentException(sprintf('The Position property can only contain items of type \StructType\Position, %s given', is_object($item) ? get_class($item) : (is_array($item) ? implode(', ', $item) : gettype($item))), __LINE__);
        }
        // validation for constraint: maxOccurs(4)
        if (is_array($this->Position) && count($this->Position) >= 4) {
            throw new \InvalidArgumentException(sprintf('You can\'t add anymore element to this property that already contains %s elements, the number of elements contained by the property must be less than or equal to 4', count($this->Position)), __LINE__);
        }
        $this->Position[] = $item;
        return $this;
    }
    /**
     * Get GoodsValue value
     * @return float|null
     */
    public function getGoodsValue()
    {
        return $this->GoodsValue;
    }
    /**
     * Set GoodsValue value
     * @param float $goodsValue
     * @return \StructType\ToomRewe
     */
    public function setGoodsValue($goodsValue = null)
    {
        // validation for constraint: float
        if (!is_null($goodsValue) && !(is_float($goodsValue) || is_numeric($goodsValue))) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a float value, %s given', var_export($goodsValue, true), gettype($goodsValue)), __LINE__);
        }
        // validation for constraint: fractionDigits(2)
        if (!is_null($goodsValue) && mb_strlen(mb_substr($goodsValue, false !== mb_strpos($goodsValue, '.') ? mb_strpos($goodsValue, '.') + 1 : mb_strlen($goodsValue))) > 2) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, the value must at most contain 2 fraction digits, %d given', var_export($goodsValue, true), mb_strlen(mb_substr($goodsValue, mb_strpos($goodsValue, '.') + 1))), __LINE__);
        }
        // validation for constraint: maxInclusive(9999999999.99)
        if (!is_null($goodsValue) && $goodsValue > 9999999999.99) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, the value must be numerically less than or equal to 9999999999.99', var_export($goodsValue, true)), __LINE__);
        }
        // validation for constraint: minInclusive(0.00)
        if (!is_null($goodsValue) && $goodsValue < 0.00) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, the value must be numerically greater than or equal to 0.00', var_export($goodsValue, true)), __LINE__);
        }
        // validation for constraint: pattern([1-9]{1}[0-9]{0,9}.[0-9]{2})
        if (!is_null($goodsValue) && !preg_match('/[1-9]{1}[0-9]{0,9}.[0-9]{2}/', $goodsValue)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a literal that is among the set of character sequences denoted by the regular expression [1-9]{1}[0-9]{0,9}.[0-9]{2}', var_export($goodsValue, true)), __LINE__);
        }
        // validation for constraint: totalDigits(12)
        if (!is_null($goodsValue) && mb_strlen(preg_replace('/(\D)/', '', $goodsValue)) > 12) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, the value must use at most 12 digits, "%d" given', var_export($goodsValue, true), mb_strlen(preg_replace('/(\D)/', '', $goodsValue))), __LINE__);
        }
        $this->GoodsValue = $goodsValue;
        return $this;
    }
    /**
     * Get Ordertext1 value
     * @return string|null
     */
    public function getOrdertext1()
    {
        return $this->Ordertext1;
    }
    /**
     * Set Ordertext1 value
     * @param string $ordertext1
     * @return \StructType\ToomRewe
     */
    public function setOrdertext1($ordertext1 = null)
    {
        // validation for constraint: string
        if (!is_null($ordertext1) && !is_string($ordertext1)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($ordertext1, true), gettype($ordertext1)), __LINE__);
        }
        // validation for constraint: maxLength(33)
        if (!is_null($ordertext1) && mb_strlen($ordertext1) > 33) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 33', mb_strlen($ordertext1)), __LINE__);
        }
        // validation for constraint: minLength(1)
        if (!is_null($ordertext1) && mb_strlen($ordertext1) < 1) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be greater than or equal to 1', mb_strlen($ordertext1)), __LINE__);
        }
        $this->Ordertext1 = $ordertext1;
        return $this;
    }
    /**
     * Get Ordertext2 value
     * @return string|null
     */
    public function getOrdertext2()
    {
        return $this->Ordertext2;
    }
    /**
     * Set Ordertext2 value
     * @param string $ordertext2
     * @return \StructType\ToomRewe
     */
    public function setOrdertext2($ordertext2 = null)
    {
        // validation for constraint: string
        if (!is_null($ordertext2) && !is_string($ordertext2)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($ordertext2, true), gettype($ordertext2)), __LINE__);
        }
        // validation for constraint: maxLength(33)
        if (!is_null($ordertext2) && mb_strlen($ordertext2) > 33) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 33', mb_strlen($ordertext2)), __LINE__);
        }
        // validation for constraint: minLength(1)
        if (!is_null($ordertext2) && mb_strlen($ordertext2) < 1) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be greater than or equal to 1', mb_strlen($ordertext2)), __LINE__);
        }
        $this->Ordertext2 = $ordertext2;
        return $this;
    }
    /**
     * Get Pitches value
     * @return string|null
     */
    public function getPitches()
    {
        return $this->Pitches;
    }
    /**
     * Set Pitches value
     * @param string $pitches
     * @return \StructType\ToomRewe
     */
    public function setPitches($pitches = null)
    {
        // validation for constraint: string
        if (!is_null($pitches) && !is_string($pitches)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($pitches, true), gettype($pitches)), __LINE__);
        }
        // validation for constraint: maxLength(3)
        if (!is_null($pitches) && mb_strlen($pitches) > 3) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 3', mb_strlen($pitches)), __LINE__);
        }
        // validation for constraint: minLength(1)
        if (!is_null($pitches) && mb_strlen($pitches) < 1) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be greater than or equal to 1', mb_strlen($pitches)), __LINE__);
        }
        $this->Pitches = $pitches;
        return $this;
    }
    /**
     * Get Volume value
     * @return float|null
     */
    public function getVolume()
    {
        return $this->Volume;
    }
    /**
     * Set Volume value
     * @param float $volume
     * @return \StructType\ToomRewe
     */
    public function setVolume($volume = null)
    {
        // validation for constraint: float
        if (!is_null($volume) && !(is_float($volume) || is_numeric($volume))) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a float value, %s given', var_export($volume, true), gettype($volume)), __LINE__);
        }
        // validation for constraint: maxInclusive(99.999)
        if (!is_null($volume) && $volume > 99.999) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, the value must be numerically less than or equal to 99.999', var_export($volume, true)), __LINE__);
        }
        // validation for constraint: minInclusive(0.000)
        if (!is_null($volume) && $volume < 0.000) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, the value must be numerically greater than or equal to 0.000', var_export($volume, true)), __LINE__);
        }
        // validation for constraint: pattern([0-9]{1,2}.[0-9]{3})
        if (!is_null($volume) && !preg_match('/[0-9]{1,2}.[0-9]{3}/', $volume)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a literal that is among the set of character sequences denoted by the regular expression [0-9]{1,2}.[0-9]{3}', var_export($volume, true)), __LINE__);
        }
        $this->Volume = $volume;
        return $this;
    }
    /**
     * Get LoadingunitsFP value
     * @return string|null
     */
    public function getLoadingunitsFP()
    {
        return $this->LoadingunitsFP;
    }
    /**
     * Set LoadingunitsFP value
     * @param string $loadingunitsFP
     * @return \StructType\ToomRewe
     */
    public function setLoadingunitsFP($loadingunitsFP = null)
    {
        // validation for constraint: string
        if (!is_null($loadingunitsFP) && !is_string($loadingunitsFP)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($loadingunitsFP, true), gettype($loadingunitsFP)), __LINE__);
        }
        // validation for constraint: maxLength(3)
        if (!is_null($loadingunitsFP) && mb_strlen($loadingunitsFP) > 3) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 3', mb_strlen($loadingunitsFP)), __LINE__);
        }
        // validation for constraint: minLength(1)
        if (!is_null($loadingunitsFP) && mb_strlen($loadingunitsFP) < 1) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be greater than or equal to 1', mb_strlen($loadingunitsFP)), __LINE__);
        }
        $this->LoadingunitsFP = $loadingunitsFP;
        return $this;
    }
    /**
     * Get LoadingunitsGP value
     * @return string|null
     */
    public function getLoadingunitsGP()
    {
        return $this->LoadingunitsGP;
    }
    /**
     * Set LoadingunitsGP value
     * @param string $loadingunitsGP
     * @return \StructType\ToomRewe
     */
    public function setLoadingunitsGP($loadingunitsGP = null)
    {
        // validation for constraint: string
        if (!is_null($loadingunitsGP) && !is_string($loadingunitsGP)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($loadingunitsGP, true), gettype($loadingunitsGP)), __LINE__);
        }
        // validation for constraint: maxLength(3)
        if (!is_null($loadingunitsGP) && mb_strlen($loadingunitsGP) > 3) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be less than or equal to 3', mb_strlen($loadingunitsGP)), __LINE__);
        }
        // validation for constraint: minLength(1)
        if (!is_null($loadingunitsGP) && mb_strlen($loadingunitsGP) < 1) {
            throw new \InvalidArgumentException(sprintf('Invalid length of %s, the number of characters/octets contained by the literal must be greater than or equal to 1', mb_strlen($loadingunitsGP)), __LINE__);
        }
        $this->LoadingunitsGP = $loadingunitsGP;
        return $this;
    }
}
